@@ -4,8 +4,8 @@ use crate::pyo3_prelude::*;
 use num_bigint::BigUint;
 
 use super::{
-    algebraic_rewrite::add_make_broadcasts_explicit, Add, Circuit, CircuitNode, CircuitRc, Concat,
-    Einsum, GeneralFunction, Index,
+    algebraic_rewrite::add_make_broadcasts_explicit, prelude::*, Add, Concat, Einsum,
+    GeneralFunction, Index,
 };
 use crate::{
     tensor_util::{TensorAxisIndex, TensorIndex, USlice},
