@@ -67,6 +67,10 @@ impl CircuitNode for ArrayConstant {
         hasher
     }
 
+    fn max_non_input_size(&self) -> BigUint {
+        Default::default()
+    }
+
     fn eval_tensors(
         &self,
         _tensors: &[Tensor],
