@@ -233,11 +233,10 @@ pub trait CircuitNode: CircuitNodePrivate {
             is_explicitly_computable: self.compute_is_explicitly_computable(),
             can_be_sampled: self.compute_can_be_sampled(),
             hash: hasher.finalize().into(),
-            max_non_input_size: BigUint::from(0usize),
+            max_non_input_size: self.max_non_input_size(),
             device_dtype: self.compute_device_dtype()?,
             named_axes,
         };
-        self.info_mut().max_non_input_size = self.max_non_input_size();
         Ok(self)
     }
 
